@@ -62,8 +62,8 @@ class TestModels(ModelsBaseTest):
             "time_done": None,
             "state_name": "wait",
             "state_reason": None,
-            "source": u"testmodule-master",
-            "owner": u"me",
+            "source": "testmodule-master",
+            "owner": "me",
             "result_repo": "http://localhost/odcs/odcs-1/compose/Temporary",
             "result_repofile": "http://localhost/odcs/odcs-1/compose/Temporary/odcs-1.repo",
             "time_submitted": c.json()["time_submitted"],
